/**********************************************************************
* File: Adc.c
* Devices: TMS320F2837xD
* Author: C2000 Technical Training, Texas Instruments
**********************************************************************/

#include "SONG.h"				// Main include file


/**********************************************************************
* Function: InitAdca()
*
* Description: Initializes ADC-A on the F2837xD
**********************************************************************/
void InitAdca(void)
{

    //--- Reset the ADC.  This is good programming practice.
    SysCtl_resetPeripheral(SYSCTL_PERIPH_RES_ADCA);     // Reset ADC

    //--- Configure the ADC-A base registers
    ADC_disableConverter(ADCA_BASE);                                        // Power down ADC for configuration
    ADC_setMode(ADCA_BASE, ADC_RESOLUTION_12BIT, ADC_MODE_SINGLE_ENDED);    // 12-bit mode, single-ended
    ADC_setPrescaler(ADCA_BASE, ADC_CLK_DIV_4_0);                           // ADC clock prescaler = CPUCLK/4
    ADC_setInterruptPulseMode(ADCA_BASE, ADC_PULSE_END_OF_CONV);            // INT pulse generation = end of conversion

    //--- SOC0 configuration - Trigger using ePWM2-ADCSOCA; Convert channel ADCINA5; Acquisition window = 20 cycles
    ADC_setupSOC(ADCA_BASE, ADC_SOC_NUMBER0, ADC_TRIGGER_EPWM2_SOCA, ADC_CH_ADCIN5, 20);

    //--- No ADC interrupt triggers SOC0 (TRIGSEL determined by SOC and not ADCINT1 or ADCINT2)
    ADC_setInterruptSOCTrigger(ADCA_BASE, ADC_SOC_NUMBER0, ADC_INT_SOC_TRIGGER_NONE);
    ADC_setSOCPriority(ADCA_BASE, ADC_PRI_ALL_ROUND_ROBIN);             // All SOCs handled in round-robin mode

    //--- ADCA1 interrupt configuration
    ADC_enableContinuousMode(ADCA_BASE, ADC_INT_NUMBER1);                       // Interrupt pulses regardless of flag state
    ADC_setInterruptSource(ADCA_BASE, ADC_INT_NUMBER1, ADC_SOC_NUMBER0);        // EOC0 triggers the interrupt
    ADC_enableInterrupt(ADCA_BASE, ADC_INT_NUMBER1);                            // Enable the interrupt in the ADC

    //--- Enable ADCA1 interrupt
    Interrupt_register(INT_ADCA1, &adcA5ISR);    // Re-map ADCA1 interrupt signal to call the ISR function
    Interrupt_enable(INT_ADCA1);                 // Enable ADCA1 in PIE group 1 and enable INT1 in IER to enable PIE group 1

    //--- Finish up
    ADC_enableConverter(ADCA_BASE);             // Power up the ADC
    DEVICE_DELAY_US(1000);                      // Wait 1 ms after power-up before using the ADC

//        EALLOW;
//        AdcaRegs.ADCCTL2.bit.PRESCALE = 6;          // Set ADCCLK divider to /4
//        AdcaRegs.ADCCTL2.bit.RESOLUTION = 0;        // 12-bit resolution
//        AdcaRegs.ADCCTL2.bit.SIGNALMODE = 0;        // Single-ended channel conversions (12-bit mode only)
//        AdcaRegs.ADCCTL1.bit.INTPULSEPOS = 1;       // Set pulse positions to late
//        AdcaRegs.ADCCTL1.bit.ADCPWDNZ = 1;          // Power up the ADC
//        DEVICE_DELAY_US(1000);                             // Delay for 1ms to allow ADC time to power up
//        EDIS;
//
//        EALLOW;
//        // Assumes ePWM clock is already enabled
//        EPwm2Regs.TBCTL.bit.CTRMODE = 3;            // Freeze counter
//        EPwm2Regs.TBCTL.bit.HSPCLKDIV = 0;          // TBCLK pre-scaler = /1
//        EPwm2Regs.TBPRD = 0x07D0;                   // Set period to 2000 counts (50kHz)
//        EPwm2Regs.ETSEL.bit.SOCAEN  = 0;            // Disable SOC on A group
//        EPwm2Regs.ETSEL.bit.SOCASEL = 2;            // Select SOCA on period match
//        EPwm2Regs.ETSEL.bit.SOCAEN = 1;             // Enable SOCA
//        EPwm2Regs.ETPS.bit.SOCAPRD = 1;             // Generate pulse on 1st event
//        EDIS;
//
//        EALLOW;
//        AdcaRegs.ADCSOC0CTL.bit.CHSEL = 5;          // SOC0 will convert pin A0
//        AdcaRegs.ADCSOC0CTL.bit.ACQPS = 14;         // Sample window is 100 SYSCLK cycles
//        AdcaRegs.ADCSOC0CTL.bit.TRIGSEL = 7;        // Trigger on ePWM2 SOCA/C
//        AdcaRegs.ADCINTSEL1N2.bit.INT1SEL = 0;      // End of SOC0 will set INT1 flag
//        AdcaRegs.ADCINTSEL1N2.bit.INT1E = 1;        // Enable INT1 flag
//        AdcaRegs.ADCINTFLGCLR.bit.ADCINT1 = 1;      // Make sure INT1 flag is cleared
//        EDIS;
//
//        EALLOW;
//        PieVectTable.ADCA1_INT = &adcA5ISR;    // Function for ADCA interrupt 1
//        EDIS;
//
//        // Enable PIE interrupt
//        PieCtrlRegs.PIEIER1.bit.INTx1 = 1;
//
//        // Enable global interrupts and higher priority real-time debug events
//        IER |= M_INT1;          // Enable group 1 interrupts
//        EINT;                   // Enable Global interrupt INTM
//        ERTM;                   // Enable Global real-time interrupt DBGM
//
//        // Sync ePWM
//        EALLOW;
//        CpuSysRegs.PCLKCR0.bit.TBCLKSYNC = 1;
//        EDIS;
//
//        // Start ePWM
//        EPwm2Regs.TBCTL.bit.CTRMODE = 0;            // Un-freeze and enter up-count mode


} // end InitAdca()

void InitAdcb(void)
{
    //--- Reset the ADC.  This is good programming practice.
    SysCtl_resetPeripheral(SYSCTL_PERIPH_RES_ADCB);     // Reset ADC

    //--- Configure the ADC-A base registers
    ADC_disableConverter(ADCB_BASE);                                        // Power down ADC for configuration
    ADC_setMode(ADCB_BASE, ADC_RESOLUTION_12BIT, ADC_MODE_SINGLE_ENDED);    // 12-bit mode, single-ended
    ADC_setPrescaler(ADCB_BASE, ADC_CLK_DIV_4_0);                           // ADC clock prescaler = CPUCLK/4
    ADC_setInterruptPulseMode(ADCB_BASE, ADC_PULSE_END_OF_CONV);            // INT pulse generation = end of conversion

    //--- SOC0 configuration - Trigger using ePWM2-ADCSOCA; Convert channel ADCINA0; Acquisition window = 20 cycles
    ADC_setupSOC(ADCB_BASE, ADC_SOC_NUMBER0, ADC_TRIGGER_EPWM2_SOCA, ADC_CH_ADCIN4, 20);

    //--- No ADC interrupt triggers SOC0 (TRIGSEL determined by SOC and not ADCINT1 or ADCINT2)
    ADC_setInterruptSOCTrigger(ADCB_BASE, ADC_SOC_NUMBER0, ADC_INT_SOC_TRIGGER_NONE);
    ADC_setSOCPriority(ADCB_BASE, ADC_PRI_ALL_ROUND_ROBIN);             // All SOCs handled in round-robin mode

    //--- ADCA1 interrupt configuration
    ADC_enableContinuousMode(ADCB_BASE, ADC_INT_NUMBER1);                       // Interrupt pulses regardless of flag state
    ADC_setInterruptSource(ADCB_BASE, ADC_INT_NUMBER1, ADC_SOC_NUMBER0);        // EOC0 triggers the interrupt
    ADC_enableInterrupt(ADCB_BASE, ADC_INT_NUMBER1);                            // Enable the interrupt in the ADC

    //--- Enable ADCA1 interrupt
    Interrupt_register(INT_ADCB1, &adcB4ISR);    // Re-map ADCB1 interrupt signal to call the ISR function
    Interrupt_enable(INT_ADCB1);                 // Enable ADCB1 in PIE group 1 and enable INT1 in IER to enable PIE group 1

    //--- Finish up
    ADC_enableConverter(ADCB_BASE);             // Power up the ADC
    DEVICE_DELAY_US(1000);                      // Wait 1 ms after power-up before using the ADC

} // end InitAdcB()

void InitAdcc(void)
{
    //--- Reset the ADC.  This is good programming practice.
    SysCtl_resetPeripheral(SYSCTL_PERIPH_RES_ADCC);     // Reset ADC

    //--- Configure the ADC-C base registers
    ADC_disableConverter(ADCC_BASE);                                        // Power down ADC for configuration
    ADC_setMode(ADCC_BASE, ADC_RESOLUTION_12BIT, ADC_MODE_SINGLE_ENDED);    // 12-bit mode, single-ended
    ADC_setPrescaler(ADCB_BASE, ADC_CLK_DIV_4_0);                           // ADC clock prescaler = CPUCLK/4
    ADC_setInterruptPulseMode(ADCC_BASE, ADC_PULSE_END_OF_CONV);            // INT pulse generation = end of conversion

    //--- SOC0 configuration - Trigger using ePWM2-ADCSOCA; Convert channel ADCINA0; Acquisition window = 20 cycles
    ADC_setupSOC(ADCC_BASE, ADC_SOC_NUMBER0, ADC_TRIGGER_EPWM2_SOCA, ADC_CH_ADCIN4, 20);

    //--- No ADC interrupt triggers SOC0 (TRIGSEL determined by SOC and not ADCINT1 or ADCINT2)
    ADC_setInterruptSOCTrigger(ADCC_BASE, ADC_SOC_NUMBER0, ADC_INT_SOC_TRIGGER_NONE);
    ADC_setSOCPriority(ADCC_BASE, ADC_PRI_ALL_ROUND_ROBIN);             // All SOCs handled in round-robin mode

    //--- ADCA1 interrupt configuration
    ADC_enableContinuousMode(ADCC_BASE, ADC_INT_NUMBER1);                       // Interrupt pulses regardless of flag state
    ADC_setInterruptSource(ADCC_BASE, ADC_INT_NUMBER1, ADC_SOC_NUMBER0);        // EOC0 triggers the interrupt
    ADC_enableInterrupt(ADCC_BASE, ADC_INT_NUMBER1);                            // Enable the interrupt in the ADC

    //--- Enable ADCA1 interrupt
    Interrupt_register(INT_ADCC1, &adcC4ISR);    // Re-map ADCB1 interrupt signal to call the ISR function
    Interrupt_enable(INT_ADCC1);                 // Enable ADCB1 in PIE group 1 and enable INT1 in IER to enable PIE group 1

    //--- Finish up
    ADC_enableConverter(ADCC_BASE);             // Power up the ADC
    DEVICE_DELAY_US(1000);                      // Wait 1 ms after power-up before using the ADC

} // end InitAdcC()

//--- end of file -----------------------------------------------------
