/**********************************************************************
* File: Gpio.c
* Devices: TMS320F2837xD
* Author: C2000 Technical Training, Texas Instruments
**********************************************************************/

#include "SONG.h"						// Main include file


/**********************************************************************
* Function: InitGpio()
*
* Description: Initializes the shared GPIO pins on the F2837xD
**********************************************************************/
void InitGpio(void)
{
//--- Unlock the configuration registers for pins on all ports
	Device_initGPIO();                              // (FILE: device.c)

//--- Configure GPIO1 for LM5170 DIR
	GPIO_setPadConfig(LM5170_DIR, GPIO_PIN_TYPE_STD);  // Push-Pull output on GPIO1
    GPIO_setPinConfig(GPIO_1_GPIO1);                   // GPIO1 = GPIO1
    GPIO_setDirectionMode(LM5170_DIR, GPIO_DIR_MODE_OUT);      // GPIO1 = output

////--- Configure GPIOXX for Master Enable for LM5170
//    GPIO_setPadConfig(LM5170_EN, GPIO_PIN_TYPE_STD);  // Push-Pull output on GPIO2
//    GPIO_setPinConfig(GPIO_2_GPIO2);                   // GPIO2 = GPIO2
//    GPIO_setDirectionMode(LM5170_EN, GPIO_DIR_MODE_OUT);      // GPIOXX = output

    //--- Configure EPWM2A on GPIO0 for ISETD
    GPIO_setPadConfig(2, GPIO_PIN_TYPE_PULLUP);     // Enable pull-up on GPIO2
    GPIO_setPinConfig(GPIO_2_EPWM2A);               // GPIO2 = EPWM2A

//--- Configure GPIO61 for Battery Source Relay Control:
    GPIO_setPadConfig(BATT_RELAY, GPIO_PIN_TYPE_STD);  // Push-Pull output on GPIO61
    GPIO_setPinConfig(GPIO_61_GPIO61);                   // GPIO61 = GPIO61
    GPIO_setDirectionMode(BATT_RELAY, GPIO_DIR_MODE_OUT);      // GPIO61 = output

//--- Configure EPWM1A on GPIO0 for ISETD
    GPIO_setPadConfig(0, GPIO_PIN_TYPE_PULLUP);     // Enable pull-up on GPIO0
    GPIO_setPinConfig(GPIO_0_EPWM1A);               // GPIO0 = EPWM1A

//--- Configure EPWM3A on GPIO4 for ISETD
    GPIO_setPadConfig(4, GPIO_PIN_TYPE_PULLUP);     // Enable pull-up on GPIO0
    GPIO_setPinConfig(GPIO_4_EPWM3A);               // GPIO0 = EPWM1A
	
//--- Configure GPIO24 as input for ECAP1 via INPUT X-BAR (used in Lab 7)
    GPIO_setPadConfig(24, GPIO_PIN_TYPE_PULLUP);    // Enable pull-up on GPIO24
    GPIO_setPinConfig(GPIO_24_GPIO24);              // GPIO24 = GPIO24	
    GPIO_setQualificationMode(24, GPIO_QUAL_SYNC);  // Synch to SYSCLKOUT
    GPIO_setDirectionMode(24, GPIO_DIR_MODE_IN);    // GPIO24 = input
    XBAR_setInputPin(XBAR_INPUT7, 24);              // GPIO24 = ECAP1	

//--- Configure GPIO34 as output (connected to LED)
    GPIO_setPadConfig(34, GPIO_PIN_TYPE_PULLUP);     // Enable pull-up on GPIO34
    GPIO_setPinConfig(GPIO_34_GPIO34);               // GPIO34 = GPIO34
    GPIO_setDirectionMode(34, GPIO_DIR_MODE_OUT);    // GPIO34 = output
    GPIO_writePin(34, 0);                            // Load output latch
	
//--- Configure GPIO19 as output (used in Lab 6 - pin high)
    GPIO_setPadConfig(19, GPIO_PIN_TYPE_PULLUP);     // Enable pull-up on GPIO19
    GPIO_setPinConfig(GPIO_19_GPIO19);               // GPIO19 = GPIO19
    GPIO_setDirectionMode(19, GPIO_DIR_MODE_OUT);    // GPIO19 = output
    GPIO_writePin(19, 1);                            // Load output latch

//--- Configure GPIO18 as output (used in Lab 6 - pin toggle)
    GPIO_setPadConfig(18, GPIO_PIN_TYPE_PULLUP);     // Enable pull-up on GPIO18
    GPIO_setPinConfig(GPIO_18_GPIO18);               // GPIO18 = GPIO18
    GPIO_setDirectionMode(18, GPIO_DIR_MODE_OUT);    // GPIO18 = output


} // end InitGpio()


//--- end of file -----------------------------------------------------
