/*
 * SONG.h
 *
 *  Created on: Apr 5, 2021
 *      Author: Joe
 */

#ifndef SONG_H_
#define SONG_H_

//---------------------------------------------------------------------------
// Constant Definitions
//
#define ADC_BUF_LEN         50              // ADC buffer length
#define ADC_SAMPLE_PERIOD   1000            // 1000 = 100 kHz sampling w/ 100 MHz ePWM clock (UP MODE)
#define PWM_PERIOD          2500           // Period = 20 kHz symmetric PWM w/ 100 MHz ePWM clock (UP/DOWN MODE)
#define PWM_DUTY_CYCLE      1250           // 50% duty cycle
#define PWM_MIN_DUTY        250           // 10% duty cycle for PWM modulation
#define PWM_MAX_DUTY        250            // 90% duty cycle for PWM modulation
#define PWM_STEP            10              // Step size change for PWM modulation
#define FILTER_LEN          5               // filter length
#define SINE_PTS            25              // number of point in sine wave

#define BLINKY_LED_GPIO    31
#define BLINKY_RLED_GPIO   34

#define LM5170_DIR          1
#define LM5170_EN           2
#define BATT_RELAY          61
//---------------------------------------------------------------------------
// Include Standard C Language Header Files
// (Header file <string.h> not supported by CLA compiler)
//
#if !defined(__TMS320C28XX_CLA__)
    #include <string.h>
#endif


//---------------------------------------------------------------------------
// Include Driver Library Header Files
// (Header files <driverlib.h> and <device.h> not supported by CLA compiler)
//
#include "F28x_Project.h"
#include <stdio.h>
#include <stdlib.h>
#if !defined(__TMS320C28XX_CLA__)
    #include "driverlib.h"                     // F28004x Driver Library
    #include "device.h"                        // Device include file
#else
    #include "hw_types.h"                      // Driver Library type definitions
#endif


//---------------------------------------------------------------------------
// Function Prototypes
//
extern void Device_init(void);
extern void Device_initGPIO(void);
extern void InitAdca(void);
extern void InitAdcb(void);
extern void InitAdcc(void);
extern void InitCla(void);
extern void InitDacb(void);
extern void InitDma(void);
extern void InitECap(void);
extern void InitEPwm1(void);
extern void InitEPwm2(void);
extern void InitEPwm3(void);
extern void InitGpio(void);
extern void InitWatchdog(void);
extern float PICtrl(float ref);


//---------------------------------------------------------------------------
// Function Prototypes - ISR Declarations
//
extern interrupt void adcA5ISR(void);             // 1.1 - ADCA Interrupt 1
extern interrupt void adcB4ISR(void);             // 1.1 - ADCB Interrupt 1
extern interrupt void adcC4ISR(void);             // 1.1 - ADCC Interrupt 1
extern interrupt void wakeISR(void);              // 1.8 - Watchdog Wake Interrupt
extern interrupt void ecap1ISR(void);             // 4.1 - eCAP1 Interrupt
extern interrupt void dmaCh1ISR(void);            // 7.1 - DMA Channel 1 Interrupt
extern interrupt void cla1Isr1(void);             // 11.1 - CLA1 Interrupt 1
extern interrupt void ipc0ISR(void);              // 1.13 - IPC0 Interrupt 0
extern interrupt void ipc1ISR(void);              // 1.14 - IPC1 Interrupt 1


//---------------------------------------------------------------------------
// CLA Function Prototypes
//
extern interrupt void Cla1Task1();
extern interrupt void Cla1Task2();
extern interrupt void Cla1Task3();
extern interrupt void Cla1Task4();
extern interrupt void Cla1Task5();
extern interrupt void Cla1Task6();
extern interrupt void Cla1Task7();
extern interrupt void Cla1Task8();


//---------------------------------------------------------------------------
// Global symbols defined in the linker command file
//
extern uint16_t Cla1ProgLoadStart;
extern uint16_t Cla1ProgLoadSize;
extern uint16_t Cla1ProgRunStart;
extern uint16_t RamfuncsLoadStart;
extern uint16_t RamfuncsLoadSize;
extern uint16_t RamfuncsRunStart;


//---------------------------------------------------------------------------
// Global Variables References
//
extern float32_t xDelay[FILTER_LEN];
extern float32_t coeffs[FILTER_LEN];
extern uint16_t AdcABuf[ADC_BUF_LEN];
extern uint16_t AdcBBuf[ADC_BUF_LEN];
extern uint16_t AdcCBuf[ADC_BUF_LEN];
extern uint16_t AdcBufFiltered[ADC_BUF_LEN];
extern uint16_t AdcBufRaw[2*ADC_BUF_LEN];
extern uint16_t ClaFilteredOutput;
extern uint16_t AdcResult;

//Battery Parameters:
static float Ilim = 7.0;

//Global Variables needed for Implementation:
static volatile uint16_t PwmCmpaVal = PWM_MIN_DUTY;        // Duty cycle variable to be used in EPWM_setCounterCompareValue() call
static volatile float v48 = 0.0;
static volatile float v12 = 0.0;
static volatile float iout = 0.0;
static volatile float Vref = 0.0;
static volatile uint16_t G = 1000;  //For PV Converter Implementation
static volatile float SOC = 0.8;

//PI Controller Global Variables:
static float Kp = 0.1;
static float Ki = 0.01;
static float deltat = 1/(50000); //Defined as time period of sampling frequency, since it is assumed that current stays constant until next measurement
static float error;

#endif /* SONG_H_ */
//--- end of file -----------------------------------------------------
