//#############################################################################
//
// FILE:   empty_driverlib_main.c
//
// TITLE:  Empty Project
//
// Empty Project Example
//
// This example is an empty project setup for Driverlib development.
//
//#############################################################################
// $TI Release: F2837xD Support Library v3.09.00.00 $
// $Release Date: Thu Mar 19 07:35:24 IST 2020 $
// $Copyright:
// Copyright (C) 2013-2020 Texas Instruments Incorporated - http://www.ti.com/
//
// Redistribution and use in source and binary forms, with or without 
// modification, are permitted provided that the following conditions 
// are met:
// 
//   Redistributions of source code must retain the above copyright 
//   notice, this list of conditions and the following disclaimer.
// 
//   Redistributions in binary form must reproduce the above copyright
//   notice, this list of conditions and the following disclaimer in the 
//   documentation and/or other materials provided with the   
//   distribution.
// 
//   Neither the name of Texas Instruments Incorporated nor the names of
//   its contributors may be used to endorse or promote products derived
//   from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// $
//#############################################################################

//
// Included Files
//

//Note: Use EPWM_setCounterCompareValue(.....) to change duty cycle for ISETD
//#include "F28x_Project.h"
//#include "driverlib.h"
//#include "device.h"
#include "SONG.h"


uint16_t AdcABuf[ADC_BUF_LEN];             // ADC buffer allocation
uint16_t AdcBBuf[ADC_BUF_LEN];             // ADC buffer allocation
uint16_t AdcCBuf[ADC_BUF_LEN];             // ADC buffer allocation

static float Iref = 0.0;
static float duty = 0.0;

//
// Main
//
void main(void)
{
//--- CPU Initialization
    Device_init();                      // Initialize device and peripherals clock (FILE: device.c)
    Interrupt_initModule();             // Initializes PIE, clear PIE registers, disables CPU interrupts, and clear all CPU interrupt flags (FILE: interrupt.c)
    Interrupt_initVectorTable();        // Initialize the PIE vector table with pointers to the shell interrupt Service Routines (FILE: interrupt.c)
    Device_initGPIO();

    GPIO_setPadConfig(BLINKY_RLED_GPIO, GPIO_PIN_TYPE_PULLUP);     // Enable pull-up on GPIO34
    GPIO_setPinConfig(GPIO_34_GPIO34);               // GPIO34 = GPIO34
    GPIO_setDirectionMode(BLINKY_RLED_GPIO, GPIO_DIR_MODE_OUT);    // GPIO34 = output
//    GPIO_writePin(34, 0);                            // Load output latch

    //--- Configure GPIO31 as output (connected to LED)
    GPIO_setPadConfig(BLINKY_LED_GPIO, GPIO_PIN_TYPE_PULLUP);     // Enable pull-up on GPIO34
    GPIO_setPinConfig(GPIO_31_GPIO31);               // GPIO34 = GPIO34
    GPIO_setDirectionMode(BLINKY_LED_GPIO, GPIO_DIR_MODE_OUT);    // GPIO34 = output

    //Initialization:
    InitGpio();
    InitEPwm1();
    InitEPwm2();
    InitEPwm3();
    InitAdca();
    InitAdcb();
    InitAdcc();

    //--- Enable global interrupts and real-time debug
    EINT;                               // Enable global interrupts - defined as: asm(" clrc INTM"); (FILE: cpu.h)
    ERTM;                               // Enable real-time debug - defined as: asm(" clrc DBGM"); (FILE: cpu.h)

    for(;;) {
//        GPIO_writePin(BLINKY_LED_GPIO, 1);
        GPIO_writePin(BLINKY_RLED_GPIO, 1);

        //Battery Converter Off:
        if (v48 > 48.5) {
//            GPIO_writePin(LM5170_EN, 0);
        }

        //Battery Converter On:
        if (v48 < 47.5) {
//            GPIO_writePin(LM5170_EN, 1);

            //Direction Control of LM5170: Assuming that Iout < 0 is charging current -> VERIFY THIS EXPERIMENTALLY
            if (iout < 0) {
                GPIO_writePin(LM5170_DIR, 1);  //Setting LM5170 in Buck Mode for charging
            } else {
                GPIO_writePin(LM5170_DIR, 0);  //Setting LM5170 in Boost Mode for discharging
            }

            //Generating Current reference for Converter Current Controller:
            Iref = PICtrl(Vref); //Use outer voltage PI loop to determine this
            if (Iref > Ilim) {
                Iref = Ilim;
            }
            if (Iref < 0) {
                Iref = 0;
            }

            duty = Iref/(20*3.125);
            if (duty > 0.48) { //Saturating duty cycle within LM5170 bounds
                duty = 0.48;
            }
            if (duty < 0) {
                duty = 0;
            }
            PwmCmpaVal = (1-duty)*PWM_PERIOD;   //Update ISETD PWM duty cycle on EPWM_1A
            EPWM_setCounterCompareValue(EPWM1_BASE, EPWM_COUNTER_COMPARE_A, PWM_DUTY_CYCLE);
        }
    }
}

float PICtrl(float ref) {
    float err_temp;
    float err_prev;

    err_prev = error;
    error = ref - v48;
    err_temp = Kp*error;
    error = error+(Ki * deltat * 0.5 * (err_prev+error));
    return (error+err_temp);

}

//
// End of File
//
